@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -36,24 +36,21 @@ class Message(Entity, StatusMixin):
     messages is taken from the e-mail system. So it is pretty similar to an
     e-mail message.
 
-    :param from: the :class:`~stalker.models.user.User` object sending the
-      message
+    :param from: the :class:`.User` object sending the message.
 
-    :param to: the list of :class:`~stalker.models.user.User`\ s to
-      receive this message
+    :param to: the list of :class:`.User`\ s to receive this message
 
     :param subject: the subject of the message
 
     :param body: the body of the message
 
-    :param in_reply_to: the :class:`~stalker.models.message.Message`
-      object which this message is a reply to.
+    :param in_reply_to: the :class:`.Message` object which this message is a
+      reply to.
 
-    :param replies: the list of :class:`~stalker.models.message.Message`
-      objects which are the direct replies of this message
+    :param replies: the list of :class:`.Message` objects which are the direct
+      replies of this message
 
-    :param attachments: a list of
-      :class:`~stalker.models.entity.SimpleEntity` objects attached to
+    :param attachments: a list of :class:`.SimpleEntity` objects attached to
       this message (so anything can be attached to a message)
 
     """
