@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -19,8 +19,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 import unittest2
+from stalker.db import DBSession
 from stalker.models.auth import User, Group
-from stalker.db.session import DBSession
 
 
 class GroupTester(unittest2.TestCase):
@@ -32,14 +32,12 @@ class GroupTester(unittest2.TestCase):
         """sets the test in class level
         """
         DBSession.remove()
-        DBSession.configure(extension=None)
 
     @classmethod
     def tearDownClass(cls):
         """clear the test in class level
         """
         DBSession.remove()
-        DBSession.configure(extension=None)
 
     def setUp(self):
         """set up the test in method level
