@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -20,10 +20,9 @@
 
 import unittest2
 
-from stalker import db, TicketLog
 from stalker.db.session import DBSession
-from stalker import (Asset, User, Note, Project, Repository, Status,
-                     StatusList, Task, Ticket, Type, Version)
+from stalker import (db, TicketLog, Asset, User, Note, Project, Repository,
+                     Status, StatusList, Task, Ticket, Type, Version, defaults)
 
 from stalker import log
 import logging
@@ -41,9 +40,26 @@ class TicketTester(unittest2.TestCase):
         """
         # create the db
         DBSession.remove()
-        DBSession.configure(extension=None)
         db.setup()
-        db.init()
+        # db.init()
+        # we just need statuses so create them instead of initializing the db
+        db.create_ticket_statuses()
+        db.create_entity_statuses(entity_type='Task',
+                                  status_names=defaults.task_status_names,
+                                  status_codes=defaults.task_status_codes)
+        db.create_entity_statuses(entity_type='Asset',
+                                  status_names=defaults.task_status_names,
+                                  status_codes=defaults.task_status_codes)
+        db.create_entity_statuses(entity_type='Shot',
+                                  status_names=defaults.task_status_names,
+                                  status_codes=defaults.task_status_codes)
+        db.create_entity_statuses(entity_type='Sequence',
+                                  status_names=defaults.task_status_names,
+                                  status_codes=defaults.task_status_codes)
+        db.create_entity_statuses(entity_type='Review',
+                                  status_names=defaults.review_status_names,
+                                  status_codes=defaults.review_status_codes)
+
 
         # create statuses
         self.test_status1 = Status(name='N', code='N')
@@ -86,14 +102,8 @@ class TicketTester(unittest2.TestCase):
             ]
         )
 
-        self.test_task_status_list = StatusList(
-            name="Task Status List",
-            target_entity_type=Task,
-            statuses=[
-                self.test_project_status1,
-                self.test_project_status2
-            ]
-        )
+        self.test_task_status_list = StatusList.query\
+            .filter_by(target_entity_type='Task').first()
 
         # create a Project
         self.test_project = Project(
@@ -105,11 +115,8 @@ class TicketTester(unittest2.TestCase):
         )
 
         # create an Asset
-        self.test_asset_status_list = StatusList(
-            name="Asset Status List",
-            target_entity_type=Asset,
-            statuses=[self.test_status1, self.test_status2]
-        )
+        self.test_asset_status_list = StatusList.query\
+            .filter_by(target_entity_type='Asset').first()
 
         self.test_asset_type = Type(
             name='Character Asset',
@@ -178,9 +185,7 @@ class TicketTester(unittest2.TestCase):
     def tearDownClass(cls):
         """clean up the test
         """
-        # revert the session back to the normal state
         DBSession.remove()
-        DBSession.configure(extension=None)
 
     def test___auto_name__class_attribute_is_set_to_True(self):
         """testing if the __auto_name__ class attribute is set to True for
@@ -395,7 +400,7 @@ class TicketTester(unittest2.TestCase):
     def test_status_for_newly_created_tickets_will_be_NEW_when_skipped(self):
         """testing if the status of newly created tickets will be New
         """
-        # get the status NEW from the DBSession
+        # get the status NEW from the session
         new_ticket = Ticket(**self.kwargs)
         self.assertEqual(new_ticket.status, self.status_new)
 
